@@ -1,9 +1,16 @@
 #ifndef RXVT_DAEMON_H
 #define RXVT_DAEMON_H
 
+#include <limits.h>
+
+#ifndef PATH_MAX
+# define PATH_MAX 16384
+#endif
+
 #include "rxvtutil.h"
 
-struct rxvt_connection {
+struct rxvt_connection
+{
   int fd;
 
   static char *unix_sockname ();
